@@ -27,9 +27,8 @@ class Dashboard(object):
         self.quiet = False
         self._project = None
         self._experiment_name = None
-        self._project_kwargs = kwargs
-
-        self._server = "FREE"
+        
+        self._server = kwargs.get('server', "EXPLORE")
         self._experiment_uuid = None
         self._token = None
         self._hyper_parameter = ''
@@ -154,8 +153,7 @@ class Dashboard(object):
         # 2.step 创建项目(获得 experiment_uuid)
         response = \
             self.rpc.experiment.post(task_name=self.project,
-                                     experiment_name=self.experiment_name
-                                     **self._project_kwargs)
+                                     experiment_name=self.experiment_name)
         experiment_uuid = None
         if response['status'] == "OK":
             experiment_uuid = response['content']['experiment_uuid']
@@ -173,7 +171,7 @@ class Dashboard(object):
     def activate(self, project, experiment):
         if project is None or experiment is None:
             print('must set project and experiment')
-            return
+            return None
 
         # 1.step 获得experiment_uuid
         response = self.rpc.experiment.activate.get(experiment_name=experiment, project_name=project)
@@ -184,8 +182,10 @@ class Dashboard(object):
             print('activate experiment %s/%s'%(response['content']['project_name'], response['content']['experiment_name']))
             # 更新rpc的实验标识字段
             self.rpc.data.update({'experiment_uuid': self.experiment_uuid})
+            return self.experiment_uuid
         else:
             print('couldnt activate %s/%s'%(project, experiment))
+            return None
 
     def list(self, project=None):
         response = self.rpc.experiment.list.get(project_name=project)
