@@ -72,17 +72,20 @@ def config(ip, port, project=None, experiment=None, token=None, **kwargs):
     
 def update():
     global __env
-    __env.dashboard.update()
+    if __env.dashboard is not None:
+        __env.dashboard.update()
     
     
 def exit():
     global __env
-    __env.dashboard.exit()
+    if __env.dashboard is not None:
+        __env.dashboard.exit()
 
 
 def error():
     global __env
-    __env.dashboard.error()
+    if __env.dashboard is not None:
+        __env.dashboard.error()
 
 
 def create_project(project, experiment):
@@ -141,16 +144,10 @@ def Context(ip, port, project, experiment, token=None, path='.'):
     tag.note.content = ''               # a descriptive note about experiment run
     tag.runname = ''                    # human readable name that identify experiment run
 
-    try:
-        yield
-    except:
-        # 实验错误
-        error()
-        return
+    yield
 
     # 更新&退出
     update()
-    exit()
 
 
 class Tag(object):
@@ -177,7 +174,7 @@ class Tag(object):
 
                 data = mlogger.getEnv().dashboard.rpc.experiment.tag.get(tag=self._parent)
                 if data['status'] == 'OK':
-                    return data['content']
+                    return data['content']['value']
 
                 return ''
             return _func
